summaryrefslogtreecommitdiffstats
path: root/pyanaconda/iw/partition_gui.py
diff options
context:
space:
mode:
Diffstat (limited to 'pyanaconda/iw/partition_gui.py')
-rw-r--r--pyanaconda/iw/partition_gui.py10
1 files changed, 5 insertions, 5 deletions
diff --git a/pyanaconda/iw/partition_gui.py b/pyanaconda/iw/partition_gui.py
index de3b45c60..95197bf6d 100644
--- a/pyanaconda/iw/partition_gui.py
+++ b/pyanaconda/iw/partition_gui.py
@@ -1564,12 +1564,12 @@ class PartitionWindow(InstallWindow):
return
self.stripeGraph.shutDown()
- # temporarily unset storage.clearPartType so that all devices will be
- # found during storage reset
- clearPartType = self.storage.clearPartType
- self.storage.clearPartType = None
+ # temporarily unset storage.config.clearPartType so that all devices
+ # will be found during storage reset
+ clearPartType = self.storage.config.clearPartType
+ self.storage.config.clearPartType = None
self.storage.reset()
- self.storage.clearPartType = clearPartType
+ self.storage.config.clearPartType = clearPartType
self.tree.clear()
self.populate()